Change Log
==========

asyncprawcore follows `semantic versioning <http://semver.org/>`_ with the
exception that deprecations will not be announced by a minor release.


* Updated upto version 1.4.0 of prawcore

* Forked from `praw-dev/prawcore <https://github.com/praw-dev/prawcore>`_